﻿using System;
using System.Collections.Generic;
using System.IO.Compression;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;

namespace TestingPosScale
{
    public static class Logger
    {
        private static readonly string _executingFolder = Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location);

        public static readonly string DetailedLogFolder = Path.Combine(_executingFolder, "detailed_logs");
        public static readonly string LogFile = Path.Combine(_executingFolder, "log.txt");

        public static void Log(Level level, string logText)
        {
            WriteLogEntry($"[{level.ToString().ToUpper()}]  {logText}{Environment.NewLine}");
        }

        public static void Log(Level level, Exception e)
        {
            var sb = new StringBuilder();

            sb.AppendLine($"[{level.ToString().ToUpper()}]  [{e.GetType()}]");
            sb.AppendLine(e.ToString());
            sb.AppendLine("");

            WriteLogEntry(sb.ToString());
        }

        public static void Log(Level level, string logText, Exception e)
        {
            var sb = new StringBuilder();

            sb.AppendLine($"[{level.ToString().ToUpper()}]  {logText} - [{ e.GetType()}]");
            sb.AppendLine(e.ToString());
            sb.AppendLine("");

            WriteLogEntry(sb.ToString());
        }

        private static void WriteLogEntry(string logText)
        {
            string currentDateTime = DateTime.Now.ToString("yyyy-MM-dd HH:mm:ss.fff");
            bool writeLog = true;
            int i = 0;

            while (writeLog && i < 5)
            {
                try
                {
                    i++;

                    File.AppendAllText(LogFile, $"{currentDateTime}  {logText}");

                    writeLog = false;
                }
                catch { }
            }
        }

        public enum Level
        {
            Debug,
            Error,
            Fatal,
            Fine,
            Info,
            None,
            Severe,
            Warning
        }
    }
}
